#
# spec file for package xfce4-fsguard-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin fsguard
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.1.3
Release:        bp156.1.5
Summary:        Filesystem Space Monitoring Plugin for the Xfce Panel
License:        BSD-2-Clause
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-fsguard-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.1/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= %{panel_version}
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
# uses exo-open
Requires:       exo-tools
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The FSGuard plugin constantly monitors free space of a given mountpoint and
displays it as an icon in the panel.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libfsguard.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/xfce4/panel/plugins/libfsguard.so
%{_datadir}/xfce4/panel/plugins/fsguard.desktop
%{_datadir}/icons/hicolor/*/apps/xfce4-fsguard-plugin*

%files lang -f %{name}.lang

%changelog
* Thu Apr 20 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.3
  * Fix autotools warnings
  * Update copyright year
  * build: Add GLib requirement
  * Fix blurry icons when UI scale > 1
  * build: Fix intltool lock file problem during make distcheck
  * autoconf: Some updates
  * Update `.gitignore`
  * Translation Updates
- Remove _service file
* Mon Dec 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.1.2
  * Improve spacing in settings dialog (bxo#14665)
  * Fix "ISO C90 forbids mixed declarations and code"
  * Modernize the configure.ac.in file
  * Remove GSourceFunc casts
  * Replace obsolete xfce_create_panel_button usage
  * Adds new README.md updates AM_INIT_AUTOMAKE
  * Add basic GitLab pipeline
  * Add gitignore
  * Update URLs from goodies.x.o to docs.x.o (bxo#16163)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Aug 13 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.1.1
  * Translation updates
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omi Changelog
- Move COPYING under %%license macro
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to version 1.1.0
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
* Tue Mar  3 2015 gber@opensuse.org
- update to version 1.0.2
  - properly resize image _and_ btn so that the image is not
    shrinked
  - updated translations
* Sun Jul  1 2012 gber@opensuse.org
- update to version 1.0.1
  - better compliance with panel plugin HIG
  - fix look on transparent/colored panels
  - added compatibility with xfce4-panel v.4.9.0+
  - fix config loading
  - port to libxfce4ui
  - build the plugin as a module
- dropped obsolete xfce4-fsguard-plugin-fix-config-loading.patch
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Fri Apr 20 2012 gber@opensuse.org
- corrected license
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Sun Apr 15 2012 gber@opensuse.org
- recommend -lang subpackage
* Tue Apr  3 2012 gber@opensuse.org
- added xfce4-fsguard-plugin-fix-config-loading.patch in order to
  fix the loading of the configuration file
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
